# cs207-FinalProject

## Group Number: #10

### Group Member:

- Nenya Edjah
- Laura Levin
- Hayden Sansum
- Catharine Wu

[![Build Status](https://travis-ci.org/fire-breathing-rubber-lemons/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/fire-breathing-rubber-lemons/cs207-FinalProject)

[![codecov](https://codecov.io/gh/fire-breathing-rubber-lemons/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/fire-breathing-rubber-lemons/cs207-FinalProject)
